use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007004
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Capture
Dagfinn
David
Golden
Graham
Ilmari
Knop
Mannsåker
Peter
Rabbitson
Tiny
UTF
Wheeler
dagolden
david
fecundf
haarg
ilmari
lib
not
prototyped
resending
ribasushi
seekable
undiagnosed
